@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from abc import abstractmethod, ABC, abstractproperty
 from typing import List, Any, Callable
 
@@ -35,7 +37,7 @@ class TraverserMatch(ABC):
         self.remembered_on_catch_action = remembered_on_catch_action
 
     @property
-    def path_as_list(self) -> List[Any]:
+    def path_as_list(self) -> List[TraverserMatch]:
         path_as_list = self._path_as_list
         if path_as_list != self:
             return path_as_list
@@ -71,7 +73,7 @@ class TraverserMatch(ABC):
         return self.real_data_name
 
     @property
-    def parent(self):
+    def parent(self) -> TraverserMatch:
         return self.real_parent
 
     @property
